"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PaymentEventType(str, Enum):
    r"""The type of payment event associated with the ACH transaction"""

    PAYROLL = "Payroll"
    CONTRACTOR_PAYMENT = "ContractorPayment"


class AchTransactionRecipientType(str, Enum):
    r"""The type of recipient associated with the ACH transaction"""

    EMPLOYEE = "Employee"
    CONTRACTOR = "Contractor"


class PaymentStatus(str, Enum):
    r"""The status of the ACH transaction"""

    UNSUBMITTED = "unsubmitted"
    SUBMITTED = "submitted"
    SUCCESSFUL = "successful"
    FAILED = "failed"


class PaymentDirection(str, Enum):
    r"""The direction of the payment"""

    CREDIT = "credit"
    DEBIT = "debit"


class AchTransactionTypedDict(TypedDict):
    r"""Representation of an ACH transaction"""

    uuid: str
    r"""Unique identifier of an ACH transaction"""
    company_uuid: NotRequired[str]
    r"""Unique identifier of the company to which the ACH transaction belongs"""
    payment_event_type: NotRequired[PaymentEventType]
    r"""The type of payment event associated with the ACH transaction"""
    payment_event_uuid: NotRequired[str]
    r"""Unique identifier for the payment event associated with the ACH transaction"""
    recipient_type: NotRequired[AchTransactionRecipientType]
    r"""The type of recipient associated with the ACH transaction"""
    recipient_uuid: NotRequired[str]
    r"""Unique identifier for the recipient associated with the ACH transaction"""
    error_code: NotRequired[str]
    r"""The error code associated with the ACH transaction, if any. If there is no error on the ACH transaction, this field will be nil. See [this article](https://engineering.gusto.com/how-ach-works-a-developer-perspective-part-2/) for a complete list of ACH return codes."""
    transaction_type: NotRequired[str]
    r"""The type of transaction associated with the ACH transaction"""
    payment_status: NotRequired[PaymentStatus]
    r"""The status of the ACH transaction"""
    payment_direction: NotRequired[PaymentDirection]
    r"""The direction of the payment"""
    payment_event_check_date: NotRequired[str]
    r"""The date of the payment event check associated with the ACH transaction"""
    payment_date: NotRequired[str]
    r"""The date of the payment associated with the ACH transaction"""
    amount: NotRequired[str]
    r"""The amount of money moved by the ACH transaction. This amount is always non-negative."""
    description: NotRequired[str]
    r"""The description of the ACH transaction. Can be used to identify the ACH transaction on the recipient's bank statement."""


class AchTransaction(BaseModel):
    r"""Representation of an ACH transaction"""

    uuid: str
    r"""Unique identifier of an ACH transaction"""

    company_uuid: Optional[str] = None
    r"""Unique identifier of the company to which the ACH transaction belongs"""

    payment_event_type: Optional[PaymentEventType] = None
    r"""The type of payment event associated with the ACH transaction"""

    payment_event_uuid: Optional[str] = None
    r"""Unique identifier for the payment event associated with the ACH transaction"""

    recipient_type: Optional[AchTransactionRecipientType] = None
    r"""The type of recipient associated with the ACH transaction"""

    recipient_uuid: Optional[str] = None
    r"""Unique identifier for the recipient associated with the ACH transaction"""

    error_code: Optional[str] = None
    r"""The error code associated with the ACH transaction, if any. If there is no error on the ACH transaction, this field will be nil. See [this article](https://engineering.gusto.com/how-ach-works-a-developer-perspective-part-2/) for a complete list of ACH return codes."""

    transaction_type: Optional[str] = None
    r"""The type of transaction associated with the ACH transaction"""

    payment_status: Optional[PaymentStatus] = None
    r"""The status of the ACH transaction"""

    payment_direction: Optional[PaymentDirection] = None
    r"""The direction of the payment"""

    payment_event_check_date: Optional[str] = None
    r"""The date of the payment event check associated with the ACH transaction"""

    payment_date: Optional[str] = None
    r"""The date of the payment associated with the ACH transaction"""

    amount: Optional[str] = None
    r"""The amount of money moved by the ACH transaction. This amount is always non-negative."""

    description: Optional[str] = None
    r"""The description of the ACH transaction. Can be used to identify the ACH transaction on the recipient's bank statement."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from gusto_embedded.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class RecoveryCaseStatus(str, Enum):
    r"""Status of the recovery case"""

    OPEN = "open"
    REDEBIT_INITIATED = "redebit_initiated"
    WIRE_INITIATED = "wire_initiated"
    RECOVERED = "recovered"
    LOST = "lost"


class RecoveryCaseTypedDict(TypedDict):
    r"""Representation of a recovery case"""

    uuid: str
    r"""Unique identifier of an recovery case"""
    company_uuid: NotRequired[str]
    r"""Unique identifier of the company to which the recovery case belongs"""
    status: NotRequired[RecoveryCaseStatus]
    r"""Status of the recovery case"""
    latest_error_code: NotRequired[str]
    r"""The latest bank error code for the recovery case. See [this doc](https://docs.gusto.com/embedded-payroll/docs/ach-codes-and-transaction-types) for a list of common ACH return codes."""
    original_debit_date: NotRequired[str]
    r"""Date when funds were originally debited from the company's bank account"""
    check_date: NotRequired[str]
    r"""Check date for the associated payroll or contractor payments"""
    payroll_uuid: NotRequired[str]
    r"""The uuid of the associated payroll for which the recovery case was created. If the recovery case was created for a contractor payment, this field will be null."""
    contractor_payment_uuids: NotRequired[List[str]]
    r"""The uuids of the associated contractor payments for which the recovery case was created. If the recovery case was created for a payroll, this field will be null."""
    amount_outstanding: NotRequired[str]
    r"""Amount outstanding for the recovery case"""
    event_total_amount: NotRequired[str]
    r"""Total amount to be debited from the payroll or contractor payments"""


class RecoveryCase(BaseModel):
    r"""Representation of a recovery case"""

    uuid: str
    r"""Unique identifier of an recovery case"""

    company_uuid: Optional[str] = None
    r"""Unique identifier of the company to which the recovery case belongs"""

    status: Optional[RecoveryCaseStatus] = None
    r"""Status of the recovery case"""

    latest_error_code: Optional[str] = None
    r"""The latest bank error code for the recovery case. See [this doc](https://docs.gusto.com/embedded-payroll/docs/ach-codes-and-transaction-types) for a list of common ACH return codes."""

    original_debit_date: Optional[str] = None
    r"""Date when funds were originally debited from the company's bank account"""

    check_date: Optional[str] = None
    r"""Check date for the associated payroll or contractor payments"""

    payroll_uuid: Optional[str] = None
    r"""The uuid of the associated payroll for which the recovery case was created. If the recovery case was created for a contractor payment, this field will be null."""

    contractor_payment_uuids: Optional[List[str]] = None
    r"""The uuids of the associated contractor payments for which the recovery case was created. If the recovery case was created for a payroll, this field will be null."""

    amount_outstanding: Optional[str] = None
    r"""Amount outstanding for the recovery case"""

    event_total_amount: Optional[str] = None
    r"""Total amount to be debited from the payroll or contractor payments"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .versionheader import VersionHeader
from gusto_embedded.types import BaseModel
from gusto_embedded.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PutV1EmployeeFormSignRequestBodyTypedDict(TypedDict):
    signature_text: str
    r"""The signature"""
    agree: bool
    r"""Whether you agree to sign electronically"""
    signed_by_ip_address: NotRequired[str]
    r"""The IP address of the signatory who signed the form. Both IPv4 AND IPv6 are supported. You must provide the IP address with either this parameter OR you can leave out this parameter and set the IP address in the request header using the `x-gusto-client-ip` header instead."""
    preparer: NotRequired[bool]
    r"""Whether there is a preparer"""
    preparer_first_name: NotRequired[str]
    preparer_last_name: NotRequired[str]
    preparer_street_1: NotRequired[str]
    preparer_street_2: NotRequired[str]
    preparer_city: NotRequired[str]
    preparer_state: NotRequired[str]
    preparer_zip: NotRequired[str]
    preparer_agree: NotRequired[str]
    r"""Whether preparer agrees to sign electronically"""
    preparer2: NotRequired[bool]
    r"""Whether there is a 2nd preparer"""
    preparer2_first_name: NotRequired[str]
    preparer2_last_name: NotRequired[str]
    preparer2_street_1: NotRequired[str]
    preparer2_street_2: NotRequired[str]
    preparer2_city: NotRequired[str]
    preparer2_state: NotRequired[str]
    preparer2_zip: NotRequired[str]
    preparer2_agree: NotRequired[str]
    r"""Whether 2nd preparer agrees to sign electronically"""
    preparer3: NotRequired[bool]
    r"""Whether there is a 3rd preparer"""
    preparer3_first_name: NotRequired[str]
    preparer3_last_name: NotRequired[str]
    preparer3_street_1: NotRequired[str]
    preparer3_street_2: NotRequired[str]
    preparer3_city: NotRequired[str]
    preparer3_state: NotRequired[str]
    preparer3_zip: NotRequired[str]
    preparer3_agree: NotRequired[str]
    r"""Whether 3rd preparer agrees to sign electronically"""
    preparer4: NotRequired[bool]
    r"""Whether there is a 4th preparer"""
    preparer4_first_name: NotRequired[str]
    preparer4_last_name: NotRequired[str]
    preparer4_street_1: NotRequired[str]
    preparer4_street_2: NotRequired[str]
    preparer4_city: NotRequired[str]
    preparer4_state: NotRequired[str]
    preparer4_zip: NotRequired[str]
    preparer4_agree: NotRequired[str]
    r"""Whether 4th preparer agrees to sign electronically"""


class PutV1EmployeeFormSignRequestBody(BaseModel):
    signature_text: str
    r"""The signature"""

    agree: bool
    r"""Whether you agree to sign electronically"""

    signed_by_ip_address: Optional[str] = None
    r"""The IP address of the signatory who signed the form. Both IPv4 AND IPv6 are supported. You must provide the IP address with either this parameter OR you can leave out this parameter and set the IP address in the request header using the `x-gusto-client-ip` header instead."""

    preparer: Optional[bool] = None
    r"""Whether there is a preparer"""

    preparer_first_name: Optional[str] = None

    preparer_last_name: Optional[str] = None

    preparer_street_1: Optional[str] = None

    preparer_street_2: Optional[str] = None

    preparer_city: Optional[str] = None

    preparer_state: Optional[str] = None

    preparer_zip: Optional[str] = None

    preparer_agree: Optional[str] = None
    r"""Whether preparer agrees to sign electronically"""

    preparer2: Optional[bool] = None
    r"""Whether there is a 2nd preparer"""

    preparer2_first_name: Optional[str] = None

    preparer2_last_name: Optional[str] = None

    preparer2_street_1: Optional[str] = None

    preparer2_street_2: Optional[str] = None

    preparer2_city: Optional[str] = None

    preparer2_state: Optional[str] = None

    preparer2_zip: Optional[str] = None

    preparer2_agree: Optional[str] = None
    r"""Whether 2nd preparer agrees to sign electronically"""

    preparer3: Optional[bool] = None
    r"""Whether there is a 3rd preparer"""

    preparer3_first_name: Optional[str] = None

    preparer3_last_name: Optional[str] = None

    preparer3_street_1: Optional[str] = None

    preparer3_street_2: Optional[str] = None

    preparer3_city: Optional[str] = None

    preparer3_state: Optional[str] = None

    preparer3_zip: Optional[str] = None

    preparer3_agree: Optional[str] = None
    r"""Whether 3rd preparer agrees to sign electronically"""

    preparer4: Optional[bool] = None
    r"""Whether there is a 4th preparer"""

    preparer4_first_name: Optional[str] = None

    preparer4_last_name: Optional[str] = None

    preparer4_street_1: Optional[str] = None

    preparer4_street_2: Optional[str] = None

    preparer4_city: Optional[str] = None

    preparer4_state: Optional[str] = None

    preparer4_zip: Optional[str] = None

    preparer4_agree: Optional[str] = None
    r"""Whether 4th preparer agrees to sign electronically"""


class PutV1EmployeeFormSignRequestTypedDict(TypedDict):
    employee_id: str
    r"""The UUID of the employee"""
    form_id: str
    r"""The UUID of the form"""
    request_body: PutV1EmployeeFormSignRequestBodyTypedDict
    x_gusto_client_ip: NotRequired[str]
    r"""Optional header to supply the IP address. This can be used to supply the IP address for signature endpoints instead of the signed_by_ip_address parameter."""
    x_gusto_api_version: NotRequired[VersionHeader]
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""


class PutV1EmployeeFormSignRequest(BaseModel):
    employee_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The UUID of the employee"""

    form_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The UUID of the form"""

    request_body: Annotated[
        PutV1EmployeeFormSignRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    x_gusto_client_ip: Annotated[
        Optional[str],
        pydantic.Field(alias="x-gusto-client-ip"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""Optional header to supply the IP address. This can be used to supply the IP address for signature endpoints instead of the signed_by_ip_address parameter."""

    x_gusto_api_version: Annotated[
        Optional[VersionHeader],
        pydantic.Field(alias="X-Gusto-API-Version"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_04_01
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .tax_requirement_metadata import (
    TaxRequirementMetadata,
    TaxRequirementMetadataTypedDict,
)
from gusto_embedded.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


TaxRequirementValueTypedDict = TypeAliasType(
    "TaxRequirementValueTypedDict", Union[bool, str, float]
)
r"""The required value of the requirement identified by `key`"""


TaxRequirementValue = TypeAliasType("TaxRequirementValue", Union[bool, str, float])
r"""The required value of the requirement identified by `key`"""


class ApplicableIfTypedDict(TypedDict):
    key: NotRequired[str]
    r"""An identifier for an individual requirement. Uniqueness is guaranteed within a requirement set."""
    value: NotRequired[Nullable[TaxRequirementValueTypedDict]]
    r"""The required value of the requirement identified by `key`"""


class ApplicableIf(BaseModel):
    key: Optional[str] = None
    r"""An identifier for an individual requirement. Uniqueness is guaranteed within a requirement set."""

    value: OptionalNullable[TaxRequirementValue] = UNSET
    r"""The required value of the requirement identified by `key`"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["key", "value"]
        nullable_fields = ["value"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class TaxRequirementTypedDict(TypedDict):
    key: NotRequired[str]
    r"""An identifier for an individual requirement. Uniqueness is guaranteed within a requirement set."""
    applicable_if: NotRequired[List[ApplicableIfTypedDict]]
    r"""An array of references to other requirements within the requirement set. This requirement is only applicable if all referenced requirements have values matching the corresponding `value`. The primary use-case is dynamically hiding and showing requirements as values change. E.g. Show Requirement-B when Requirement-A has been answered with `false`. To be explicit, an empty array means the requirement is applicable."""
    label: NotRequired[str]
    r"""A customer facing description of the requirement"""
    description: NotRequired[str]
    r"""A more detailed customer facing description of the requirement"""
    value: NotRequired[Nullable[str]]
    r"""The \"answer\" """
    metadata: NotRequired[TaxRequirementMetadataTypedDict]


class TaxRequirement(BaseModel):
    key: Optional[str] = None
    r"""An identifier for an individual requirement. Uniqueness is guaranteed within a requirement set."""

    applicable_if: Optional[List[ApplicableIf]] = None
    r"""An array of references to other requirements within the requirement set. This requirement is only applicable if all referenced requirements have values matching the corresponding `value`. The primary use-case is dynamically hiding and showing requirements as values change. E.g. Show Requirement-B when Requirement-A has been answered with `false`. To be explicit, an empty array means the requirement is applicable."""

    label: Optional[str] = None
    r"""A customer facing description of the requirement"""

    description: Optional[str] = None
    r"""A more detailed customer facing description of the requirement"""

    value: OptionalNullable[str] = UNSET
    r"""The \"answer\" """

    metadata: Optional[TaxRequirementMetadata] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "key",
            "applicable_if",
            "label",
            "description",
            "value",
            "metadata",
        ]
        nullable_fields = ["value"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from gusto_embedded.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


class TaxRequirementMetadataType(str, Enum):
    r"""Describes the type of requirement - each type may have additional metadata properties to describe possible values, formats, etc.

    - `text`: free-text input, no additional requirements
    - `currency`: a value representing a dollar amount, e.g. `374.55` representing `$374.55`
    - `radio`: choose one of options provided, see `options`
    - `select`: choose one of options provided, see `options`
    - `percent`: A decimal value representing a percentage, e.g. `0.034` representing `3.4%`
    - `account_number`: An account number for a tax agency, more information provided by `mask` and `prefix`
    - `tax_rate`: A decimal value representing a tax rate, e.g. `0.034` representing a tax rate of `3.4%`, see `validation` for additional validation guidance
    - `workers_compensation_rate`: A decimal value representing a percentage, see `risk_class_code`, `risk_class_description`, and `rate_type`

    """

    TEXT = "text"
    CURRENCY = "currency"
    RADIO = "radio"
    SELECT = "select"
    PERCENT = "percent"
    ACCOUNT_NUMBER = "account_number"
    TAX_RATE = "tax_rate"
    WORKERS_COMPENSATION_RATE = "workers_compensation_rate"


TaxRequirementMetadataValueTypedDict = TypeAliasType(
    "TaxRequirementMetadataValueTypedDict", Union[str, bool]
)
r"""The actual value to be submitted"""


TaxRequirementMetadataValue = TypeAliasType(
    "TaxRequirementMetadataValue", Union[str, bool]
)
r"""The actual value to be submitted"""


class TaxRequirementMetadataOptionsTypedDict(TypedDict):
    label: str
    r"""A customer facing label for the answer"""
    value: TaxRequirementMetadataValueTypedDict
    r"""The actual value to be submitted"""
    short_label: NotRequired[str]
    r"""A less verbose label that may sometimes be available"""


class TaxRequirementMetadataOptions(BaseModel):
    label: str
    r"""A customer facing label for the answer"""

    value: TaxRequirementMetadataValue
    r"""The actual value to be submitted"""

    short_label: Optional[str] = None
    r"""A less verbose label that may sometimes be available"""


class RateType(str, Enum):
    r"""[for `workers_compensation_rate`] The type of rate being collected. Either:
    - `percent`: A percentage formatted as a decimal, e.g. `0.01` for 1%
    - `currency_per_hour`: A dollar amount per hour, e.g. `3.24` for $3.24/hr

    """

    PERCENT = "percent"
    CURRENCY_PER_HOUR = "currency_per_hour"


class TaxRequirementMetadataValidationType(str, Enum):
    r"""Describes the type of tax_rate validation rule"""

    ONE_OF = "one_of"
    MIN_MAX = "min_max"


class ValidationTypedDict(TypedDict):
    r"""[for `tax_rate`] Describes the validation required for the tax rate"""

    type: TaxRequirementMetadataValidationType
    r"""Describes the type of tax_rate validation rule"""
    min: NotRequired[str]
    r"""[for `min_max`] The inclusive lower bound of the tax rate"""
    max: NotRequired[str]
    r"""[for `min_max`] The inclusive upper bound of the tax rate"""
    rates: NotRequired[List[str]]
    r"""[for `one_of`] The possible, unformatted tax rates for selection.
    - e.g. [\"0.0\", \"0.001\"] representing 0% and 0.1%

    """


class Validation(BaseModel):
    r"""[for `tax_rate`] Describes the validation required for the tax rate"""

    type: TaxRequirementMetadataValidationType
    r"""Describes the type of tax_rate validation rule"""

    min: Optional[str] = None
    r"""[for `min_max`] The inclusive lower bound of the tax rate"""

    max: Optional[str] = None
    r"""[for `min_max`] The inclusive upper bound of the tax rate"""

    rates: Optional[List[str]] = None
    r"""[for `one_of`] The possible, unformatted tax rates for selection.
    - e.g. [\"0.0\", \"0.001\"] representing 0% and 0.1%

    """


class TaxRequirementMetadataTypedDict(TypedDict):
    type: TaxRequirementMetadataType
    r"""Describes the type of requirement - each type may have additional metadata properties to describe possible values, formats, etc.

    - `text`: free-text input, no additional requirements
    - `currency`: a value representing a dollar amount, e.g. `374.55` representing `$374.55`
    - `radio`: choose one of options provided, see `options`
    - `select`: choose one of options provided, see `options`
    - `percent`: A decimal value representing a percentage, e.g. `0.034` representing `3.4%`
    - `account_number`: An account number for a tax agency, more information provided by `mask` and `prefix`
    - `tax_rate`: A decimal value representing a tax rate, e.g. `0.034` representing a tax rate of `3.4%`, see `validation` for additional validation guidance
    - `workers_compensation_rate`: A decimal value representing a percentage, see `risk_class_code`, `risk_class_description`, and `rate_type`

    """
    options: NotRequired[List[TaxRequirementMetadataOptionsTypedDict]]
    r"""[for `select` or `radio`] An array of objects describing the possible values."""
    risk_class_code: NotRequired[str]
    r"""[for `workers_compensation_rate`] The industry risk class code for the rate being requested"""
    risk_class_description: NotRequired[str]
    r"""[for `workers_compensation_rate`] A description of the industry risk class for the rate being requested"""
    rate_type: NotRequired[RateType]
    r"""[for `workers_compensation_rate`] The type of rate being collected. Either:
    - `percent`: A percentage formatted as a decimal, e.g. `0.01` for 1%
    - `currency_per_hour`: A dollar amount per hour, e.g. `3.24` for $3.24/hr

    """
    mask: NotRequired[Nullable[str]]
    r"""[for `account_number`] A pattern describing the format of the account number

    The mask is a sequence of characters representing the requirements of the actual account number. Each character in the mask represents a single character in the account number as follows:
    - `#`: a digit (`\d`)
    - `@`: a upper or lower case letter (`[a-zA-Z]`)
    - `^`: an uppercase letter (`[A-Z]`)
    - `%`: a digit or uppercase letter (`[0-9A-Z]`)
    - any other character represents the literal character

    Examples:
    - mask: `WHT-######` represents `WHT-` followed by 5 digits, e.g. `WHT-33421`
    - mask: `%####-^^` supports values of `75544-AB` and `Z7654-HK`

    """
    prefix: NotRequired[Nullable[str]]
    r"""[for `account_number`] A value that precedes the value to be collected - useful for display, but should not be submitted as part of the value. E.g. some tax agencies use an account number that is a company's federal ein plus two digits. In that case the mask would be `##` and the prefix `XXXXX1234`."""
    validation: NotRequired[ValidationTypedDict]
    r"""[for `tax_rate`] Describes the validation required for the tax rate"""


class TaxRequirementMetadata(BaseModel):
    type: TaxRequirementMetadataType
    r"""Describes the type of requirement - each type may have additional metadata properties to describe possible values, formats, etc.

    - `text`: free-text input, no additional requirements
    - `currency`: a value representing a dollar amount, e.g. `374.55` representing `$374.55`
    - `radio`: choose one of options provided, see `options`
    - `select`: choose one of options provided, see `options`
    - `percent`: A decimal value representing a percentage, e.g. `0.034` representing `3.4%`
    - `account_number`: An account number for a tax agency, more information provided by `mask` and `prefix`
    - `tax_rate`: A decimal value representing a tax rate, e.g. `0.034` representing a tax rate of `3.4%`, see `validation` for additional validation guidance
    - `workers_compensation_rate`: A decimal value representing a percentage, see `risk_class_code`, `risk_class_description`, and `rate_type`

    """

    options: Optional[List[TaxRequirementMetadataOptions]] = None
    r"""[for `select` or `radio`] An array of objects describing the possible values."""

    risk_class_code: Optional[str] = None
    r"""[for `workers_compensation_rate`] The industry risk class code for the rate being requested"""

    risk_class_description: Optional[str] = None
    r"""[for `workers_compensation_rate`] A description of the industry risk class for the rate being requested"""

    rate_type: Optional[RateType] = None
    r"""[for `workers_compensation_rate`] The type of rate being collected. Either:
    - `percent`: A percentage formatted as a decimal, e.g. `0.01` for 1%
    - `currency_per_hour`: A dollar amount per hour, e.g. `3.24` for $3.24/hr

    """

    mask: OptionalNullable[str] = UNSET
    r"""[for `account_number`] A pattern describing the format of the account number

    The mask is a sequence of characters representing the requirements of the actual account number. Each character in the mask represents a single character in the account number as follows:
    - `#`: a digit (`\d`)
    - `@`: a upper or lower case letter (`[a-zA-Z]`)
    - `^`: an uppercase letter (`[A-Z]`)
    - `%`: a digit or uppercase letter (`[0-9A-Z]`)
    - any other character represents the literal character

    Examples:
    - mask: `WHT-######` represents `WHT-` followed by 5 digits, e.g. `WHT-33421`
    - mask: `%####-^^` supports values of `75544-AB` and `Z7654-HK`

    """

    prefix: OptionalNullable[str] = UNSET
    r"""[for `account_number`] A value that precedes the value to be collected - useful for display, but should not be submitted as part of the value. E.g. some tax agencies use an account number that is a company's federal ein plus two digits. In that case the mask would be `##` and the prefix `XXXXX1234`."""

    validation: Optional[Validation] = None
    r"""[for `tax_rate`] Describes the validation required for the tax rate"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "options",
            "risk_class_code",
            "risk_class_description",
            "rate_type",
            "mask",
            "prefix",
            "validation",
        ]
        nullable_fields = ["mask", "prefix"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class AccruingTimeOffHourTypedDict(TypedDict):
    r"""The representation of an unprocessed termination pay period."""

    time_off_policy_uuid: NotRequired[str]
    r"""A unique identifier of the time off policy."""
    hours: NotRequired[str]
    r"""Hours accrued during this pay period."""


class AccruingTimeOffHour(BaseModel):
    r"""The representation of an unprocessed termination pay period."""

    time_off_policy_uuid: Optional[str] = None
    r"""A unique identifier of the time off policy."""

    hours: Optional[str] = None
    r"""Hours accrued during this pay period."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .versionheader import VersionHeader
from enum import Enum
from gusto_embedded.types import BaseModel
from gusto_embedded.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PutV1EmployeesEmployeeIDI9AuthorizationAuthorizationStatus(str, Enum):
    r"""The employee's authorization status

    * `citizen`: A citizen is someone who was born in the United States or is a naturalized citizen living in the United States.
    * `noncitizen`: A noncitizen national is someone born in American Samoa, certain former citizens of the former Trust Territory of the Pacific Islands, and certain children of noncitizen nationals born abroad.
    * `permanent_resident`: A lawful permanent resident is someone who is not a US citizen and who resides under legally recognized and lawfully recorded permanent residence as an immigrant.
    * `alien`: Also referred to as a \"noncitizen authorized to work\". This includes anyone who is authorized to work in the United States but is not a US citizen, US national or lawful permanent resident.

    """

    CITIZEN = "citizen"
    NONCITIZEN = "noncitizen"
    PERMANENT_RESIDENT = "permanent_resident"
    ALIEN = "alien"


class PutV1EmployeesEmployeeIDI9AuthorizationDocumentType(str, Enum):
    r"""The type of document an employee holds, based on their authorization status.

    * This is unused for authorization status `citizen` or `noncitizen`.
    * If the authorization status is `permanent_resident`, this must be `uscis_alien_registration_number`.
    * If the authorization status is `alien`, this is required and may be any of the valid values.

    """

    USCIS_ALIEN_REGISTRATION_NUMBER = "uscis_alien_registration_number"
    FORM_I94 = "form_i94"
    FOREIGN_PASSPORT = "foreign_passport"


class PutV1EmployeesEmployeeIDI9AuthorizationRequestBodyTypedDict(TypedDict):
    authorization_status: PutV1EmployeesEmployeeIDI9AuthorizationAuthorizationStatus
    r"""The employee's authorization status

    * `citizen`: A citizen is someone who was born in the United States or is a naturalized citizen living in the United States.
    * `noncitizen`: A noncitizen national is someone born in American Samoa, certain former citizens of the former Trust Territory of the Pacific Islands, and certain children of noncitizen nationals born abroad.
    * `permanent_resident`: A lawful permanent resident is someone who is not a US citizen and who resides under legally recognized and lawfully recorded permanent residence as an immigrant.
    * `alien`: Also referred to as a \"noncitizen authorized to work\". This includes anyone who is authorized to work in the United States but is not a US citizen, US national or lawful permanent resident.

    """
    document_type: NotRequired[PutV1EmployeesEmployeeIDI9AuthorizationDocumentType]
    r"""The type of document an employee holds, based on their authorization status.

    * This is unused for authorization status `citizen` or `noncitizen`.
    * If the authorization status is `permanent_resident`, this must be `uscis_alien_registration_number`.
    * If the authorization status is `alien`, this is required and may be any of the valid values.

    """
    document_number: NotRequired[str]
    r"""The document number. Formatting depends on the employee's document type.

    * For `document_type:'uscis_alien_registration_number'`, this must be a USCIS Number/A-Number, which is 7 to 9 digits.
    * For `document_type:'form_i94'`, this must be a Form I-94 Admission Number, which is 11 digits.
    * For `document_type:'foreign_passport'`, this must be the passport number.

    This is required when the document type is present.

    """
    country: NotRequired[str]
    r"""The document's country of issuance.

    This is required when the document type is `foreign_passport`.

    """
    expiration_date: NotRequired[str]
    r"""The document's expiration date.

    This may only be used when the authorization status is `alien`.

    """
    version: NotRequired[str]
    r"""The current version of the object. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/versioning#object-layer) for information on how to use this field. If supplied, this endpoint will update the existing I-9 authorization if it exists."""


class PutV1EmployeesEmployeeIDI9AuthorizationRequestBody(BaseModel):
    authorization_status: PutV1EmployeesEmployeeIDI9AuthorizationAuthorizationStatus
    r"""The employee's authorization status

    * `citizen`: A citizen is someone who was born in the United States or is a naturalized citizen living in the United States.
    * `noncitizen`: A noncitizen national is someone born in American Samoa, certain former citizens of the former Trust Territory of the Pacific Islands, and certain children of noncitizen nationals born abroad.
    * `permanent_resident`: A lawful permanent resident is someone who is not a US citizen and who resides under legally recognized and lawfully recorded permanent residence as an immigrant.
    * `alien`: Also referred to as a \"noncitizen authorized to work\". This includes anyone who is authorized to work in the United States but is not a US citizen, US national or lawful permanent resident.

    """

    document_type: Optional[PutV1EmployeesEmployeeIDI9AuthorizationDocumentType] = None
    r"""The type of document an employee holds, based on their authorization status.

    * This is unused for authorization status `citizen` or `noncitizen`.
    * If the authorization status is `permanent_resident`, this must be `uscis_alien_registration_number`.
    * If the authorization status is `alien`, this is required and may be any of the valid values.

    """

    document_number: Optional[str] = None
    r"""The document number. Formatting depends on the employee's document type.

    * For `document_type:'uscis_alien_registration_number'`, this must be a USCIS Number/A-Number, which is 7 to 9 digits.
    * For `document_type:'form_i94'`, this must be a Form I-94 Admission Number, which is 11 digits.
    * For `document_type:'foreign_passport'`, this must be the passport number.

    This is required when the document type is present.

    """

    country: Optional[str] = None
    r"""The document's country of issuance.

    This is required when the document type is `foreign_passport`.

    """

    expiration_date: Optional[str] = None
    r"""The document's expiration date.

    This may only be used when the authorization status is `alien`.

    """

    version: Optional[str] = None
    r"""The current version of the object. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/versioning#object-layer) for information on how to use this field. If supplied, this endpoint will update the existing I-9 authorization if it exists."""


class PutV1EmployeesEmployeeIDI9AuthorizationRequestTypedDict(TypedDict):
    employee_id: str
    r"""The UUID of the employee"""
    request_body: PutV1EmployeesEmployeeIDI9AuthorizationRequestBodyTypedDict
    x_gusto_api_version: NotRequired[VersionHeader]
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""


class PutV1EmployeesEmployeeIDI9AuthorizationRequest(BaseModel):
    employee_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The UUID of the employee"""

    request_body: Annotated[
        PutV1EmployeesEmployeeIDI9AuthorizationRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    x_gusto_api_version: Annotated[
        Optional[VersionHeader],
        pydantic.Field(alias="X-Gusto-API-Version"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_04_01
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from gusto_embedded import models, utils
from gusto_embedded._hooks import HookContext
from gusto_embedded.types import OptionalNullable, UNSET
from gusto_embedded.utils import get_security_from_env
from typing import Any, List, Mapping, Optional


class ContractorForms(BaseSDK):
    def list(
        self,
        *,
        contractor_uuid: str,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_04_01,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> List[models.Form1099]:
        r"""Get all contractor forms

        Get a list of all contractor's forms

        scope: `contractor_forms:read`

        :param contractor_uuid: The UUID of the contractor
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetV1ContractorFormsRequest(
            contractor_uuid=contractor_uuid,
            x_gusto_api_version=x_gusto_api_version,
        )

        req = self._build_request(
            method="GET",
            path="/v1/contractors/{contractor_uuid}/forms",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get-v1-contractor-forms",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, List[models.Form1099])
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def list_async(
        self,
        *,
        contractor_uuid: str,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_04_01,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> List[models.Form1099]:
        r"""Get all contractor forms

        Get a list of all contractor's forms

        scope: `contractor_forms:read`

        :param contractor_uuid: The UUID of the contractor
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetV1ContractorFormsRequest(
            contractor_uuid=contractor_uuid,
            x_gusto_api_version=x_gusto_api_version,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/contractors/{contractor_uuid}/forms",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get-v1-contractor-forms",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, List[models.Form1099])
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def get(
        self,
        *,
        contractor_uuid: str,
        form_id: str,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_04_01,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.Form1099:
        r"""Get a contractor form

        Get a contractor form

        scope: `contractor_forms:read`

        :param contractor_uuid: The UUID of the contractor
        :param form_id: The UUID of the form
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetV1ContractorFormRequest(
            contractor_uuid=contractor_uuid,
            form_id=form_id,
            x_gusto_api_version=x_gusto_api_version,
        )

        req = self._build_request(
            method="GET",
            path="/v1/contractors/{contractor_uuid}/forms/{form_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get-v1-contractor-form",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.Form1099)
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def get_async(
        self,
        *,
        contractor_uuid: str,
        form_id: str,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_04_01,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.Form1099:
        r"""Get a contractor form

        Get a contractor form

        scope: `contractor_forms:read`

        :param contractor_uuid: The UUID of the contractor
        :param form_id: The UUID of the form
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetV1ContractorFormRequest(
            contractor_uuid=contractor_uuid,
            form_id=form_id,
            x_gusto_api_version=x_gusto_api_version,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/contractors/{contractor_uuid}/forms/{form_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get-v1-contractor-form",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.Form1099)
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def get_pdf(
        self,
        *,
        contractor_uuid: str,
        form_id: str,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_04_01,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.FormPdf:
        r"""Get the contractor form pdf

        Get the link to the form PDF

        scope: `contractor_forms:read`

        :param contractor_uuid: The UUID of the contractor
        :param form_id: The UUID of the form
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetV1ContractorFormPdfRequest(
            contractor_uuid=contractor_uuid,
            form_id=form_id,
            x_gusto_api_version=x_gusto_api_version,
        )

        req = self._build_request(
            method="GET",
            path="/v1/contractors/{contractor_uuid}/forms/{form_id}/pdf",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get-v1-contractor-form-pdf",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.FormPdf)
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def get_pdf_async(
        self,
        *,
        contractor_uuid: str,
        form_id: str,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_04_01,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.FormPdf:
        r"""Get the contractor form pdf

        Get the link to the form PDF

        scope: `contractor_forms:read`

        :param contractor_uuid: The UUID of the contractor
        :param form_id: The UUID of the form
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetV1ContractorFormPdfRequest(
            contractor_uuid=contractor_uuid,
            form_id=form_id,
            x_gusto_api_version=x_gusto_api_version,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1/contractors/{contractor_uuid}/forms/{form_id}/pdf",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="get-v1-contractor-form-pdf",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["404", "4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.FormPdf)
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def generate1099(
        self,
        *,
        contractor_id: str,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_04_01,
        year: Optional[int] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.Form1099:
        r"""Generate a 1099 form [DEMO]

        > 🚧 Demo action
        >
        > This action is only available in the Demo environment

        Generates a 1099 document for testing purposes.

        scope: `contractors:write`

        :param contractor_id: The contractor UUID.
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param year: Must be equal to or more recent than 2015. If not specified, defaults to the previous year.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostV1SandboxGenerate1099Request(
            x_gusto_api_version=x_gusto_api_version,
            request_body=models.PostV1SandboxGenerate1099RequestBody(
                contractor_id=contractor_id,
                year=year,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/v1/sandbox/generate_1099",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body,
                False,
                False,
                "json",
                models.PostV1SandboxGenerate1099RequestBody,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="post-v1-sandbox-generate_1099",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["404", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.Form1099)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.UnprocessableEntityErrorObjectData
            )
            raise models.UnprocessableEntityErrorObject(data=response_data)
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def generate1099_async(
        self,
        *,
        contractor_id: str,
        x_gusto_api_version: Optional[
            models.VersionHeader
        ] = models.VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_04_01,
        year: Optional[int] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.Form1099:
        r"""Generate a 1099 form [DEMO]

        > 🚧 Demo action
        >
        > This action is only available in the Demo environment

        Generates a 1099 document for testing purposes.

        scope: `contractors:write`

        :param contractor_id: The contractor UUID.
        :param x_gusto_api_version: Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used.
        :param year: Must be equal to or more recent than 2015. If not specified, defaults to the previous year.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostV1SandboxGenerate1099Request(
            x_gusto_api_version=x_gusto_api_version,
            request_body=models.PostV1SandboxGenerate1099RequestBody(
                contractor_id=contractor_id,
                year=year,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/v1/sandbox/generate_1099",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body,
                False,
                False,
                "json",
                models.PostV1SandboxGenerate1099RequestBody,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                base_url=base_url or "",
                operation_id="post-v1-sandbox-generate_1099",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["404", "422", "4XX", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, models.Form1099)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = utils.unmarshal_json(
                http_res.text, models.UnprocessableEntityErrorObjectData
            )
            raise models.UnprocessableEntityErrorObject(data=response_data)
        if utils.match_response(http_res, ["404", "4XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.APIError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CompanyBenefitTypedDict(TypedDict):
    r"""The representation of a company benefit."""

    uuid: str
    r"""The UUID of the company benefit."""
    version: NotRequired[str]
    r"""The current version of the object. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/idempotency) for information on how to use this field."""
    enrollment_count: NotRequired[int]
    r"""The number of employees enrolled in the benefit, only returned when enrollment_count query param is set to true."""
    company_uuid: NotRequired[str]
    r"""The UUID of the company."""
    benefit_type: NotRequired[int]
    r"""The type of the benefit to which the company benefit belongs."""
    active: NotRequired[bool]
    r"""Whether this benefit is active for employee participation. Company benefits may only be deactivated if no employees are actively participating."""
    description: NotRequired[str]
    r"""The description of the company benefit. For example, a company may offer multiple benefits with an ID of 1 (for Medical Insurance). The description would show something more specific like “Kaiser Permanente” or “Blue Cross/ Blue Shield”."""
    deletable: NotRequired[bool]
    r"""Whether this company benefit can be deleted. Deletable will be set to true if the benefit has not been used in payroll, has no employee benefits associated, and the benefit is not owned by Gusto or a Partner"""
    supports_percentage_amounts: NotRequired[bool]
    r"""Whether employee deductions and company contributions can be set as percentages of payroll for an individual employee. This is determined by the type of benefit and is not configurable by the company."""
    responsible_for_employer_taxes: NotRequired[bool]
    r"""Whether the employer is subject to pay employer taxes when an employee is on leave. Only applicable to third party sick pay benefits."""
    responsible_for_employee_w2: NotRequired[bool]
    r"""Whether the employer is subject to file W-2 forms for an employee on leave. Only applicable to third party sick pay benefits."""


class CompanyBenefit(BaseModel):
    r"""The representation of a company benefit."""

    uuid: str
    r"""The UUID of the company benefit."""

    version: Optional[str] = None
    r"""The current version of the object. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/idempotency) for information on how to use this field."""

    enrollment_count: Optional[int] = None
    r"""The number of employees enrolled in the benefit, only returned when enrollment_count query param is set to true."""

    company_uuid: Optional[str] = None
    r"""The UUID of the company."""

    benefit_type: Optional[int] = None
    r"""The type of the benefit to which the company benefit belongs."""

    active: Optional[bool] = True
    r"""Whether this benefit is active for employee participation. Company benefits may only be deactivated if no employees are actively participating."""

    description: Optional[str] = None
    r"""The description of the company benefit. For example, a company may offer multiple benefits with an ID of 1 (for Medical Insurance). The description would show something more specific like “Kaiser Permanente” or “Blue Cross/ Blue Shield”."""

    deletable: Optional[bool] = None
    r"""Whether this company benefit can be deleted. Deletable will be set to true if the benefit has not been used in payroll, has no employee benefits associated, and the benefit is not owned by Gusto or a Partner"""

    supports_percentage_amounts: Optional[bool] = None
    r"""Whether employee deductions and company contributions can be set as percentages of payroll for an individual employee. This is determined by the type of benefit and is not configurable by the company."""

    responsible_for_employer_taxes: Optional[bool] = None
    r"""Whether the employer is subject to pay employer taxes when an employee is on leave. Only applicable to third party sick pay benefits."""

    responsible_for_employee_w2: Optional[bool] = None
    r"""Whether the employer is subject to file W-2 forms for an employee on leave. Only applicable to third party sick pay benefits."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ReportTypedDict(TypedDict):
    r"""Example response"""

    request_uuid: NotRequired[str]
    r"""A unique identifier of the report request"""
    status: NotRequired[str]
    r"""Current status of the report, possible values are 'succeeded', 'pending', or 'failed'"""
    report_urls: NotRequired[List[str]]
    r"""The array of urls to access the report"""


class Report(BaseModel):
    r"""Example response"""

    request_uuid: Optional[str] = None
    r"""A unique identifier of the report request"""

    status: Optional[str] = None
    r"""Current status of the report, possible values are 'succeeded', 'pending', or 'failed'"""

    report_urls: Optional[List[str]] = None
    r"""The array of urls to access the report"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class PayrollWithholdingPayPeriodType(str, Enum):
    r"""The payment schedule tax rate the payroll is based on. Only included for off-cycle payrolls."""

    EVERY_WEEK = "Every week"
    EVERY_OTHER_WEEK = "Every other week"
    TWICE_PER_MONTH = "Twice per month"
    MONTHLY = "Monthly"
    QUARTERLY = "Quarterly"
    SEMIANNUALLY = "Semiannually"
    ANNUALLY = "Annually"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from gusto_embedded.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
import pydantic
from pydantic import model_serializer
from typing import List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class ValueTiersTypedDict(TypedDict):
    r"""A single tier of a tiered matching scheme."""

    rate: NotRequired[str]
    r"""The percentage of employee deduction within this tier the company contribution will match."""
    threshold: NotRequired[str]
    r"""The percentage threshold at which this tier ends (inclusive).

    For example, a value of \"5\" means the company contribution will match employee deductions from the previous tier's threshold up to and including 5% of payroll.

    If this is the first tier, a value of \"5\" means the company contribution will match employee deductions from 0% up to and including 5% of payroll.
    """
    threshold_delta: NotRequired[str]
    r"""The step up difference between this tier's threshold and the previous tier's threshold. In the first tier, this is equivalent to threshold."""


class ValueTiers(BaseModel):
    r"""A single tier of a tiered matching scheme."""

    rate: Optional[str] = None
    r"""The percentage of employee deduction within this tier the company contribution will match."""

    threshold: Optional[str] = None
    r"""The percentage threshold at which this tier ends (inclusive).

    For example, a value of \"5\" means the company contribution will match employee deductions from the previous tier's threshold up to and including 5% of payroll.

    If this is the first tier, a value of \"5\" means the company contribution will match employee deductions from 0% up to and including 5% of payroll.
    """

    threshold_delta: Optional[str] = None
    r"""The step up difference between this tier's threshold and the previous tier's threshold. In the first tier, this is equivalent to threshold."""


class Value2TypedDict(TypedDict):
    tiers: NotRequired[List[ValueTiersTypedDict]]


class Value2(BaseModel):
    tiers: Optional[List[ValueTiers]] = None


EmployeeBenefitForCompanyBenefitValueTypedDict = TypeAliasType(
    "EmployeeBenefitForCompanyBenefitValueTypedDict", Union[Value2TypedDict, str]
)
r"""For the `amount` and `percentage` contribution types, the value of the corresponding amount or percentage.

For the `tiered` contribution type, an array of tiers.
"""


EmployeeBenefitForCompanyBenefitValue = TypeAliasType(
    "EmployeeBenefitForCompanyBenefitValue", Union[Value2, str]
)
r"""For the `amount` and `percentage` contribution types, the value of the corresponding amount or percentage.

For the `tiered` contribution type, an array of tiers.
"""


class EmployeeBenefitForCompanyBenefitContributionTypedDict(TypedDict):
    r"""An object representing the type and value of the company contribution."""

    type: NotRequired[str]
    r"""The company contribution scheme.

    \"amount\": The company contributes a fixed amount per payroll. If elective is true, the contribution is matching, dollar-for-dollar.

    \"percentage\": The company contributes a percentage of the payroll amount per payroll period. If elective is true, the contribution is matching, dollar-for-dollar.

    \"tiered\": The company contribution varies according to the size of the employee deduction.
    """
    value: NotRequired[EmployeeBenefitForCompanyBenefitValueTypedDict]
    r"""For the `amount` and `percentage` contribution types, the value of the corresponding amount or percentage.

    For the `tiered` contribution type, an array of tiers.
    """


class EmployeeBenefitForCompanyBenefitContribution(BaseModel):
    r"""An object representing the type and value of the company contribution."""

    type: Optional[str] = None
    r"""The company contribution scheme.

    \"amount\": The company contributes a fixed amount per payroll. If elective is true, the contribution is matching, dollar-for-dollar.

    \"percentage\": The company contributes a percentage of the payroll amount per payroll period. If elective is true, the contribution is matching, dollar-for-dollar.

    \"tiered\": The company contribution varies according to the size of the employee deduction.
    """

    value: Optional[EmployeeBenefitForCompanyBenefitValue] = None
    r"""For the `amount` and `percentage` contribution types, the value of the corresponding amount or percentage.

    For the `tiered` contribution type, an array of tiers.
    """


class EmployeeBenefitForCompanyBenefitDeductionReducesTaxableIncome(str, Enum):
    r"""Whether the employee deduction reduces taxable income or not. Only valid for Group Term Life benefits. Note: when the value is not \"unset\", coverage amount and coverage salary multiplier are ignored."""

    UNSET = "unset"
    REDUCES_TAXABLE_INCOME = "reduces_taxable_income"
    DOES_NOT_REDUCE_TAXABLE_INCOME = "does_not_reduce_taxable_income"


class EmployeeBenefitForCompanyBenefitTypedDict(TypedDict):
    r"""The representation of an employee benefit for a company benefit."""

    employee_uuid: str
    r"""The UUID of the employee to which the benefit belongs."""
    version: NotRequired[str]
    r"""The current version of the object. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/idempotency) for information on how to use this field."""
    active: NotRequired[bool]
    r"""Whether the employee benefit is active."""
    employee_deduction: NotRequired[str]
    r"""The amount to be deducted, per pay period, from the employee's pay."""
    deduct_as_percentage: NotRequired[bool]
    r"""Whether the employee deduction amount should be treated as a percentage to be deducted from each payroll."""
    employee_deduction_annual_maximum: NotRequired[Nullable[str]]
    r"""The maximum employee deduction amount per year. A null value signifies no limit."""
    contribution: NotRequired[EmployeeBenefitForCompanyBenefitContributionTypedDict]
    r"""An object representing the type and value of the company contribution."""
    elective: NotRequired[bool]
    r"""Whether the company contribution is elective (aka matching). For \"tiered\" contribution types, this is always true."""
    company_contribution_annual_maximum: NotRequired[Nullable[str]]
    r"""The maximum company contribution amount per year. A null value signifies no limit."""
    limit_option: NotRequired[Nullable[str]]
    r"""Some benefits require additional information to determine their limit.

    `Family` and `Individual` are applicable to HSA benefit.

    `Joint Filing or Single` and `Married and Filing Separately` are applicable to Dependent Care FSA benefit.
    """
    catch_up: NotRequired[bool]
    r"""Whether the employee should use a benefit’s \"catch up\" rate. Only Roth 401k and 401k benefits use this value for employees over 50."""
    retirement_loan_identifier: NotRequired[str]
    r"""Identifier for a 401(k) loan assigned by the 401(k) provider"""
    coverage_amount: NotRequired[Nullable[str]]
    r"""The amount that the employee is insured for. Note: company contribution cannot be present if coverage amount is set."""
    deduction_reduces_taxable_income: NotRequired[
        Nullable[EmployeeBenefitForCompanyBenefitDeductionReducesTaxableIncome]
    ]
    r"""Whether the employee deduction reduces taxable income or not. Only valid for Group Term Life benefits. Note: when the value is not \"unset\", coverage amount and coverage salary multiplier are ignored."""
    coverage_salary_multiplier: NotRequired[str]
    r"""The coverage amount as a multiple of the employee’s salary. Only applicable for Group Term Life benefits. Note: cannot be set if coverage amount is also set."""
    company_contribution: NotRequired[str]
    r"""The amount to be paid, per pay period, by the company. This field will not appear for tiered contribution types."""
    contribute_as_percentage: NotRequired[bool]
    r"""Whether the company_contribution value should be treated as a percentage to be added to each payroll. This field will not appear for tiered contribution types."""


class EmployeeBenefitForCompanyBenefit(BaseModel):
    r"""The representation of an employee benefit for a company benefit."""

    employee_uuid: str
    r"""The UUID of the employee to which the benefit belongs."""

    version: Optional[str] = None
    r"""The current version of the object. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/idempotency) for information on how to use this field."""

    active: Optional[bool] = True
    r"""Whether the employee benefit is active."""

    employee_deduction: Optional[str] = "0.00"
    r"""The amount to be deducted, per pay period, from the employee's pay."""

    deduct_as_percentage: Optional[bool] = False
    r"""Whether the employee deduction amount should be treated as a percentage to be deducted from each payroll."""

    employee_deduction_annual_maximum: OptionalNullable[str] = UNSET
    r"""The maximum employee deduction amount per year. A null value signifies no limit."""

    contribution: Optional[EmployeeBenefitForCompanyBenefitContribution] = None
    r"""An object representing the type and value of the company contribution."""

    elective: Optional[bool] = False
    r"""Whether the company contribution is elective (aka matching). For \"tiered\" contribution types, this is always true."""

    company_contribution_annual_maximum: OptionalNullable[str] = UNSET
    r"""The maximum company contribution amount per year. A null value signifies no limit."""

    limit_option: OptionalNullable[str] = UNSET
    r"""Some benefits require additional information to determine their limit.

    `Family` and `Individual` are applicable to HSA benefit.

    `Joint Filing or Single` and `Married and Filing Separately` are applicable to Dependent Care FSA benefit.
    """

    catch_up: Optional[bool] = False
    r"""Whether the employee should use a benefit’s \"catch up\" rate. Only Roth 401k and 401k benefits use this value for employees over 50."""

    retirement_loan_identifier: Optional[str] = None
    r"""Identifier for a 401(k) loan assigned by the 401(k) provider"""

    coverage_amount: OptionalNullable[str] = UNSET
    r"""The amount that the employee is insured for. Note: company contribution cannot be present if coverage amount is set."""

    deduction_reduces_taxable_income: OptionalNullable[
        EmployeeBenefitForCompanyBenefitDeductionReducesTaxableIncome
    ] = EmployeeBenefitForCompanyBenefitDeductionReducesTaxableIncome.UNSET
    r"""Whether the employee deduction reduces taxable income or not. Only valid for Group Term Life benefits. Note: when the value is not \"unset\", coverage amount and coverage salary multiplier are ignored."""

    coverage_salary_multiplier: Optional[str] = "0.00"
    r"""The coverage amount as a multiple of the employee’s salary. Only applicable for Group Term Life benefits. Note: cannot be set if coverage amount is also set."""

    company_contribution: Annotated[
        Optional[str],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = "0.00"
    r"""The amount to be paid, per pay period, by the company. This field will not appear for tiered contribution types."""

    contribute_as_percentage: Annotated[
        Optional[bool],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = False
    r"""Whether the company_contribution value should be treated as a percentage to be added to each payroll. This field will not appear for tiered contribution types."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "version",
            "active",
            "employee_deduction",
            "deduct_as_percentage",
            "employee_deduction_annual_maximum",
            "contribution",
            "elective",
            "company_contribution_annual_maximum",
            "limit_option",
            "catch_up",
            "retirement_loan_identifier",
            "coverage_amount",
            "deduction_reduces_taxable_income",
            "coverage_salary_multiplier",
            "company_contribution",
            "contribute_as_percentage",
        ]
        nullable_fields = [
            "employee_deduction_annual_maximum",
            "company_contribution_annual_maximum",
            "limit_option",
            "coverage_amount",
            "deduction_reduces_taxable_income",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class PaymentSpeedParam(str, Enum):
    r"""Gusto Embedded supports three payment speeds (1-day, 2-day, and 4-day). For next-day payments, funds are deposited in your team's bank account by the end of the next business day. Most people will see the funds arrive the next afternoon, but payments may arrive as late as the end of the business day."""

    ONE_DAY = "1-day"
    TWO_DAY = "2-day"
    FOUR_DAY = "4-day"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PaymentConfigsTypedDict(TypedDict):
    r"""Example response"""

    company_uuid: NotRequired[str]
    r"""Company uuid"""
    partner_uuid: NotRequired[str]
    r"""Partner uuid"""
    fast_payment_limit: NotRequired[str]
    r"""Payment limit for 1-day or 2-day payroll"""
    payment_speed: NotRequired[str]
    r"""Payment speed for 1-day, 2-day, 4-day"""


class PaymentConfigs(BaseModel):
    r"""Example response"""

    company_uuid: Optional[str] = None
    r"""Company uuid"""

    partner_uuid: Optional[str] = None
    r"""Partner uuid"""

    fast_payment_limit: Optional[str] = None
    r"""Payment limit for 1-day or 2-day payroll"""

    payment_speed: Optional[str] = None
    r"""Payment speed for 1-day, 2-day, 4-day"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from gusto_embedded.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class Section(str, Enum):
    r"""The document option's section in the list of acceptable documents on the Form I-9"""

    A = "A"
    A1 = "A1"
    A2 = "A2"
    A3 = "A3"
    B = "B"
    C = "C"


class I9AuthorizationDocumentOptionTypedDict(TypedDict):
    r"""An employee's I-9 verification document option based on the authorization status"""

    section: Section
    r"""The document option's section in the list of acceptable documents on the Form I-9"""
    description: str
    r"""The document option's description"""
    document_type: str
    r"""The document option's document type"""
    document_title: List[str]
    r"""The document option's document titles"""
    common_choice: bool
    r"""Whether the document is a common choice for I-9 verification"""


class I9AuthorizationDocumentOption(BaseModel):
    r"""An employee's I-9 verification document option based on the authorization status"""

    section: Section
    r"""The document option's section in the list of acceptable documents on the Form I-9"""

    description: str
    r"""The document option's description"""

    document_type: str
    r"""The document option's document type"""

    document_title: List[str]
    r"""The document option's document titles"""

    common_choice: bool
    r"""Whether the document is a common choice for I-9 verification"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .entity_error_object import EntityErrorObject, EntityErrorObjectTypedDict
from enum import Enum
from gusto_embedded.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class PayrollProcessingRequestStatus(str, Enum):
    r"""The status of the payroll processing request"""

    CALCULATING = "calculating"
    CALCULATE_SUCCESS = "calculate_success"
    SUBMITTING = "submitting"
    SUBMIT_SUCCESS = "submit_success"
    PROCESSING_FAILED = "processing_failed"


class PayrollProcessingRequestTypedDict(TypedDict):
    status: NotRequired[PayrollProcessingRequestStatus]
    r"""The status of the payroll processing request"""
    errors: NotRequired[List[EntityErrorObjectTypedDict]]
    r"""Errors that occurred during async payroll processing"""


class PayrollProcessingRequest(BaseModel):
    status: Optional[PayrollProcessingRequestStatus] = None
    r"""The status of the payroll processing request"""

    errors: Optional[List[EntityErrorObject]] = None
    r"""Errors that occurred during async payroll processing"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class FlowTypedDict(TypedDict):
    r"""The representation of a flow in Gusto white-label UI."""

    url: NotRequired[str]


class Flow(BaseModel):
    r"""The representation of a flow in Gusto white-label UI."""

    url: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .compensation import Compensation, CompensationTypedDict
from gusto_embedded.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class JobTypedDict(TypedDict):
    r"""The representation of a job in Gusto."""

    uuid: str
    r"""The UUID of the job."""
    version: NotRequired[str]
    r"""The current version of the object. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/idempotency) for information on how to use this field."""
    employee_uuid: NotRequired[str]
    r"""The UUID of the employee to which the job belongs."""
    hire_date: NotRequired[str]
    r"""The date when the employee was hired or rehired for the job."""
    title: NotRequired[Nullable[str]]
    r"""The title for the job."""
    primary: NotRequired[bool]
    r"""Whether this is the employee's primary job. The value will be set to true unless an existing job exists for the employee."""
    rate: NotRequired[str]
    r"""The current compensation rate of the job."""
    payment_unit: NotRequired[str]
    r"""The payment unit of the current compensation for the job."""
    current_compensation_uuid: NotRequired[str]
    r"""The UUID of the current compensation of the job."""
    two_percent_shareholder: NotRequired[bool]
    r"""Whether the employee owns at least 2% of the company."""
    state_wc_covered: NotRequired[Nullable[bool]]
    r"""Whether this job is eligible for workers' compensation coverage in the state of Washington (WA)."""
    state_wc_class_code: NotRequired[Nullable[str]]
    r"""The risk class code for workers' compensation in Washington state. Please visit [Washington state's Risk Class page](https://www.lni.wa.gov/insurance/rates-risk-classes/risk-classes-for-workers-compensation/risk-class-lookup#/) to learn more."""
    compensations: NotRequired[List[CompensationTypedDict]]


class Job(BaseModel):
    r"""The representation of a job in Gusto."""

    uuid: str
    r"""The UUID of the job."""

    version: Optional[str] = None
    r"""The current version of the object. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/idempotency) for information on how to use this field."""

    employee_uuid: Optional[str] = None
    r"""The UUID of the employee to which the job belongs."""

    hire_date: Optional[str] = None
    r"""The date when the employee was hired or rehired for the job."""

    title: OptionalNullable[str] = None
    r"""The title for the job."""

    primary: Optional[bool] = None
    r"""Whether this is the employee's primary job. The value will be set to true unless an existing job exists for the employee."""

    rate: Optional[str] = None
    r"""The current compensation rate of the job."""

    payment_unit: Optional[str] = None
    r"""The payment unit of the current compensation for the job."""

    current_compensation_uuid: Optional[str] = None
    r"""The UUID of the current compensation of the job."""

    two_percent_shareholder: Optional[bool] = None
    r"""Whether the employee owns at least 2% of the company."""

    state_wc_covered: OptionalNullable[bool] = UNSET
    r"""Whether this job is eligible for workers' compensation coverage in the state of Washington (WA)."""

    state_wc_class_code: OptionalNullable[str] = UNSET
    r"""The risk class code for workers' compensation in Washington state. Please visit [Washington state's Risk Class page](https://www.lni.wa.gov/insurance/rates-risk-classes/risk-classes-for-workers-compensation/risk-class-lookup#/) to learn more."""

    compensations: Optional[List[Compensation]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "version",
            "employee_uuid",
            "hire_date",
            "title",
            "primary",
            "rate",
            "payment_unit",
            "current_compensation_uuid",
            "two_percent_shareholder",
            "state_wc_covered",
            "state_wc_class_code",
            "compensations",
        ]
        nullable_fields = ["title", "state_wc_covered", "state_wc_class_code"]
        null_default_fields = ["title"]

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class AdminTypedDict(TypedDict):
    r"""The representation of an admin user in Gusto."""

    uuid: str
    r"""The unique id of the admin."""
    email: NotRequired[str]
    r"""The email of the admin for Gusto's system. If the email matches an existing user, this will create an admin account for them."""
    first_name: NotRequired[str]
    r"""The first name of the admin."""
    last_name: NotRequired[str]
    r"""The last name of the admin."""


class Admin(BaseModel):
    r"""The representation of an admin user in Gusto."""

    uuid: str
    r"""The unique id of the admin."""

    email: Optional[str] = None
    r"""The email of the admin for Gusto's system. If the email matches an existing user, this will create an admin account for them."""

    first_name: Optional[str] = None
    r"""The first name of the admin."""

    last_name: Optional[str] = None
    r"""The last name of the admin."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class Category(str, Enum):
    r"""The category of the company attachment"""

    GEP_NOTICE = "gep_notice"
    COMPLIANCE = "compliance"
    OTHER = "other"


class CompanyAttachmentTypedDict(TypedDict):
    r"""The company attachment"""

    uuid: NotRequired[str]
    r"""UUID of the company attachment"""
    name: NotRequired[str]
    r"""name of the file uploaded"""
    category: NotRequired[Category]
    r"""The category of the company attachment"""
    upload_time: NotRequired[str]
    r"""The ISO 8601 timestamp of when an attachment was uploaded"""


class CompanyAttachment(BaseModel):
    r"""The company attachment"""

    uuid: Optional[str] = None
    r"""UUID of the company attachment"""

    name: Optional[str] = None
    r"""name of the file uploaded"""

    category: Optional[Category] = None
    r"""The category of the company attachment"""

    upload_time: Optional[str] = None
    r"""The ISO 8601 timestamp of when an attachment was uploaded"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .flsa_status_type import FlsaStatusType
from .versionheader import VersionHeader
from enum import Enum
from gusto_embedded.types import BaseModel
from gusto_embedded.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PutV1CompensationsCompensationIDPaymentUnit(str, Enum):
    r"""The unit accompanying the compensation rate. If the employee is an owner, rate should be 'Paycheck'."""

    HOUR = "Hour"
    WEEK = "Week"
    MONTH = "Month"
    YEAR = "Year"
    PAYCHECK = "Paycheck"


class PutV1CompensationsCompensationIDMinimumWagesTypedDict(TypedDict):
    r"""The minimum wage record you want to apply to the compensation"""

    uuid: NotRequired[str]
    r"""The UUID of the minimum wage record. Required if adjust_for_minimum_wage set to true"""


class PutV1CompensationsCompensationIDMinimumWages(BaseModel):
    r"""The minimum wage record you want to apply to the compensation"""

    uuid: Optional[str] = None
    r"""The UUID of the minimum wage record. Required if adjust_for_minimum_wage set to true"""


class PutV1CompensationsCompensationIDRequestBodyTypedDict(TypedDict):
    version: str
    r"""The current version of the object. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/versioning#object-layer) for information on how to use this field."""
    rate: NotRequired[str]
    r"""The dollar amount paid per payment unit."""
    payment_unit: NotRequired[PutV1CompensationsCompensationIDPaymentUnit]
    r"""The unit accompanying the compensation rate. If the employee is an owner, rate should be 'Paycheck'."""
    flsa_status: NotRequired[FlsaStatusType]
    r"""The FLSA status for this compensation. Salaried ('Exempt') employees are paid a fixed salary every pay period. Salaried with overtime ('Salaried Nonexempt') employees are paid a fixed salary every pay period, and receive overtime pay when applicable. Hourly ('Nonexempt') employees are paid for the hours they work, and receive overtime pay when applicable. Commissioned employees ('Commission Only Exempt') earn wages based only on commission. Commissioned with overtime ('Commission Only Nonexempt') earn wages based on commission, and receive overtime pay when applicable. Owners ('Owner') are employees that own at least twenty percent of the company."""
    adjust_for_minimum_wage: NotRequired[bool]
    r"""Determines whether the compensation should be adjusted for minimum wage. Only applies to Nonexempt employees."""
    minimum_wages: NotRequired[
        List[PutV1CompensationsCompensationIDMinimumWagesTypedDict]
    ]


class PutV1CompensationsCompensationIDRequestBody(BaseModel):
    version: str
    r"""The current version of the object. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/versioning#object-layer) for information on how to use this field."""

    rate: Optional[str] = None
    r"""The dollar amount paid per payment unit."""

    payment_unit: Optional[PutV1CompensationsCompensationIDPaymentUnit] = None
    r"""The unit accompanying the compensation rate. If the employee is an owner, rate should be 'Paycheck'."""

    flsa_status: Optional[FlsaStatusType] = None
    r"""The FLSA status for this compensation. Salaried ('Exempt') employees are paid a fixed salary every pay period. Salaried with overtime ('Salaried Nonexempt') employees are paid a fixed salary every pay period, and receive overtime pay when applicable. Hourly ('Nonexempt') employees are paid for the hours they work, and receive overtime pay when applicable. Commissioned employees ('Commission Only Exempt') earn wages based only on commission. Commissioned with overtime ('Commission Only Nonexempt') earn wages based on commission, and receive overtime pay when applicable. Owners ('Owner') are employees that own at least twenty percent of the company."""

    adjust_for_minimum_wage: Optional[bool] = None
    r"""Determines whether the compensation should be adjusted for minimum wage. Only applies to Nonexempt employees."""

    minimum_wages: Optional[List[PutV1CompensationsCompensationIDMinimumWages]] = None


class PutV1CompensationsCompensationIDRequestTypedDict(TypedDict):
    compensation_id: str
    r"""The UUID of the compensation"""
    request_body: PutV1CompensationsCompensationIDRequestBodyTypedDict
    x_gusto_api_version: NotRequired[VersionHeader]
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""


class PutV1CompensationsCompensationIDRequest(BaseModel):
    compensation_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The UUID of the compensation"""

    request_body: Annotated[
        PutV1CompensationsCompensationIDRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    x_gusto_api_version: Annotated[
        Optional[VersionHeader],
        pydantic.Field(alias="X-Gusto-API-Version"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_04_01
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DocumentPdfTypedDict(TypedDict):
    uuid: NotRequired[str]
    r"""the UUID of the document"""
    document_url: NotRequired[str]
    r"""the URL of the document"""


class DocumentPdf(BaseModel):
    uuid: Optional[str] = None
    r"""the UUID of the document"""

    document_url: Optional[str] = None
    r"""the URL of the document"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .versionheader import VersionHeader
from gusto_embedded.types import BaseModel
from gusto_embedded.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PutV1EmployeesEmployeeIDI9AuthorizationEmployerSignRequestBodyTypedDict(
    TypedDict
):
    signature_text: str
    r"""The signature"""
    signer_title: str
    r"""The signer's job title"""
    agree: bool
    r"""Whether you agree to sign electronically"""
    signed_by_ip_address: NotRequired[str]
    r"""The IP address of the signatory who signed the form. Both IPv4 AND IPv6 are supported. You must provide the IP address with either this parameter OR you can leave out this parameter and set the IP address in the request header using the `x-gusto-client-ip` header instead."""
    additional_info: NotRequired[str]
    r"""Any additional notes"""
    alt_procedure: NotRequired[bool]
    r"""Whether an alternative procedure authorized by DHS to examine documents was used"""


class PutV1EmployeesEmployeeIDI9AuthorizationEmployerSignRequestBody(BaseModel):
    signature_text: str
    r"""The signature"""

    signer_title: str
    r"""The signer's job title"""

    agree: bool
    r"""Whether you agree to sign electronically"""

    signed_by_ip_address: Optional[str] = None
    r"""The IP address of the signatory who signed the form. Both IPv4 AND IPv6 are supported. You must provide the IP address with either this parameter OR you can leave out this parameter and set the IP address in the request header using the `x-gusto-client-ip` header instead."""

    additional_info: Optional[str] = None
    r"""Any additional notes"""

    alt_procedure: Optional[bool] = None
    r"""Whether an alternative procedure authorized by DHS to examine documents was used"""


class PutV1EmployeesEmployeeIDI9AuthorizationEmployerSignRequestTypedDict(TypedDict):
    employee_id: str
    r"""The UUID of the employee"""
    request_body: (
        PutV1EmployeesEmployeeIDI9AuthorizationEmployerSignRequestBodyTypedDict
    )
    x_gusto_client_ip: NotRequired[str]
    r"""Optional header to supply the IP address. This can be used to supply the IP address for signature endpoints instead of the signed_by_ip_address parameter."""
    x_gusto_api_version: NotRequired[VersionHeader]
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""


class PutV1EmployeesEmployeeIDI9AuthorizationEmployerSignRequest(BaseModel):
    employee_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The UUID of the employee"""

    request_body: Annotated[
        PutV1EmployeesEmployeeIDI9AuthorizationEmployerSignRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    x_gusto_client_ip: Annotated[
        Optional[str],
        pydantic.Field(alias="x-gusto-client-ip"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""Optional header to supply the IP address. This can be used to supply the IP address for signature endpoints instead of the signed_by_ip_address parameter."""

    x_gusto_api_version: Annotated[
        Optional[VersionHeader],
        pydantic.Field(alias="X-Gusto-API-Version"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_04_01
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gusto_embedded.types import BaseModel
import pydantic
from pydantic import ConfigDict
from typing import Any, Dict, Optional
from typing_extensions import NotRequired, TypedDict


class MetadataWithOneEntityTypedDict(TypedDict):
    r"""single entity"""

    entity_type: NotRequired[str]
    r"""Name of the entity that the error corresponds to."""
    entity_uuid: NotRequired[str]
    r"""Unique identifier for the entity."""
    valid_from: NotRequired[str]
    valid_up_to: NotRequired[str]
    key: NotRequired[str]
    state: NotRequired[str]


class MetadataWithOneEntity(BaseModel):
    r"""single entity"""

    model_config = ConfigDict(
        populate_by_name=True, arbitrary_types_allowed=True, extra="allow"
    )
    __pydantic_extra__: Dict[str, Any] = pydantic.Field(init=False)

    entity_type: Optional[str] = None
    r"""Name of the entity that the error corresponds to."""

    entity_uuid: Optional[str] = None
    r"""Unique identifier for the entity."""

    valid_from: Optional[str] = None

    valid_up_to: Optional[str] = None

    key: Optional[str] = None

    state: Optional[str] = None

    @property
    def additional_properties(self):
        return self.__pydantic_extra__

    @additional_properties.setter
    def additional_properties(self, value):
        self.__pydantic_extra__ = value  # pyright: ignore[reportIncompatibleVariableOverride]
